@@ -64,6 +64,10 @@ class Base(Controller):
                          "Accepts port:messages pairs separated by commas. E.g. 42:answer to life, 22:memes",
                 "action" : "store"
             }),
+            (['-r','--region'],{
+                "help": "Which AWS region should boto3 use",
+                "action": "store"
+            }),
             (['-i','--id'],{
                 "help" : "ID of the SG to act on from the ls DataFrame",
                 "action" : "store"
@@ -74,6 +78,7 @@ class Base(Controller):
         from ..ext.aws_sg import get_sg, update_sg_to_ip
         profile = self.app.pargs.__dict__.get('profile') or self.app.pargs.__dict__.get('p') or 'default'
         name = self.app.pargs.__dict__.get('name') or self.app.pargs.__dict__.get('n')
+        region = self.app.pargs.__dict__.get('region') or self.app.pargs.__dict__.get('r') or 'eu-west-1'
 
         # which ports to change
         ports = self.app.pargs.__dict__.get('ports') or self.app.pargs.__dict__.get('P')
@@ -88,16 +93,17 @@ class Base(Controller):
         if sid: sid = int(sid)
 
         if self.app.pargs.action=='show':
-            pp(get_sg(profile, sid = sid))
+            pp(get_sg(profile, sid = sid, region=region))
 
         elif self.app.pargs.action=='update':
             if not self.app.pargs.name: sg_name = get_sg(profile, sid = sid)[0]['GroupName']
             else: sg_name = self.app.pargs.name
-            update_sg_to_ip(sg_name=sg_name, profile=profile, ports=ports, messages=messages)
+            update_sg_to_ip(sg_name=sg_name, profile=profile,
+                            ports=ports, messages=messages, region=region)
 
         elif self.app.pargs.action=='ls':
             from ..ext.aws_sg import list_security_groups
-            df = list_security_groups()
+            df = list_security_groups(region, profile)
             print(df)
 
         else:
@@ -157,17 +163,20 @@ class Base(Controller):
             (['-n'],{
                 "help": "Depth of the tree to print",
                 "action": "store"
+            }),
+            (['-f'],{
+                "help": "Print out full path",
+                "action": "store"  
             })
         ]
     )
     def tree(self):
         from ..ext.tree import tree
         
-        try:
-            level = int(self.app.pargs.n)
-        except TypeError:
-            level = 2
-        tree(self.app.pargs.loc, level)
+        level = int(self.app.pargs.n or 2)
+        full_path = int(self.app.pargs.f or 0)
+        
+        tree(self.app.pargs.loc, level, full_path)
         
 
     @ex(
@@ -237,7 +246,6 @@ class Base(Controller):
                 "help" : "To give the SFTP server a name.",
                 "action" : "store"
             }),
-            # TODO: there's some weird bug when grabbing this.
             (['-i', '--identity'],{
                 "help" : "Path to the identity file to use for ssh.",
                 "action" : "store"
@@ -249,7 +257,6 @@ class Base(Controller):
         ]
     )
     def sftp(self):
-        import ipdb; ipdb.set_trace()
         ip = self.app.pargs.ip
         remote = self.app.pargs.__dict__.get('remote') or self.app.pargs.__dict__.get('r') or '/data/openpilot'
         port = self.app.pargs.__dict__.get('port') or self.app.pargs.__dict__.get('p') or 8022
