@@ -19,19 +19,16 @@ def get_public_ip():
     # data = '<html><head><title>Current IP Check</title></head><body>Current IP Address: 65.96.168.198</body></html>\r\n'
     return re.compile(r'Address: (\d+\.\d+\.\d+\.\d+)').search(data).group(1)
 
-def get_sg(profile: str, sid: int, sg_name = None):
+def get_sg(profile: str, sid: int, sg_name = None, region='eu-west-1'):
     
     # decide if use security group name or security group id
     if sid:
         # get relevant row from security group df
-        sg_name = list_security_groups().iloc[sid]['GroupName']
+        sg_name = list_security_groups(profile=profile, region=region).iloc[sid]['GroupName']
     else:
         sg_name = 'default'
     
-    import boto3
-    profile = profile or 'default'
-
-    ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
+    ec2 = boto3.session.Session(profile_name=profile, region_name=region).client('ec2')
     resp = ec2.describe_security_groups()
     target_sg_dict = list(filter(lambda x: x['GroupName']==sg_name, resp['SecurityGroups']))
     return target_sg_dict
@@ -51,20 +48,20 @@ def check_if_exists(ip_ranges: list, descriptions: list):
 
 def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
                     ports=[22, 8888, 8501, 8889, 5432], profile='default',
-                    messages=''):
+                    messages='', region='eu-west-1'):
     import boto3
 
     ip = f"{get_public_ip()}/32"
 
-    profile = profile or 'default'
     try:
-        sid = list_security_groups().index[list_security_groups().GroupName==sg_name].tolist()[0]
+        group_name = list_security_groups(profile=profile, region=region)
+        sid = group_name.index[group_name.GroupName==sg_name].tolist()[0]
     except IndexError:
         raise ValueError(f"Security group called {sg_name} does not exist")
-    ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
+    ec2 = boto3.session.Session(profile_name=profile, region_name=region).client('ec2')
 
-    target_sg_dict = get_sg(sg_name=sg_name, sid=sid, profile=profile)[0]
-    ec2_res = boto3.session.Session(profile_name=profile, region_name='eu-west-1').resource('ec2')
+    target_sg_dict = get_sg(sg_name=sg_name, sid=sid, profile=profile, region=region)[0]
+    ec2_res = boto3.session.Session(profile_name=profile, region_name=region).resource('ec2')
     sg_res = ec2_res.SecurityGroup(target_sg_dict['GroupId'])
 
     # determine what the new sg rules should be either default or custom
@@ -110,16 +107,17 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         'ToPort': ports[i],
         'IpRanges': [{'CidrIp': ip, 'Description': descriptions[ports[i]] }]}
             for i in range(len(ports)) ]
-
+    
     data = ec2.authorize_security_group_ingress(
             GroupId=target_sg_dict['GroupId'],
             IpPermissions=ip_perms )
     print(f'Ingress Successfully Set {ip_perms} to {sg_name}')
 
 # lists all security groups
-def list_security_groups():
+def list_security_groups(region: str = 'eu-west-1', profile: str = 'default'):
     # define a boto3 client with a region eu-est
-    ec2 = boto3.client('ec2', region_name='eu-west-1')
+    boto3.setup_default_session(profile_name=profile)
+    ec2 = boto3.client('ec2', region_name=region)
     response = ec2.describe_security_groups()
     security_group_df = pd.DataFrame(response['SecurityGroups'])
 
